@@ -354,7 +354,7 @@ class Travel(object):
     def fill_with_zero(output):
         """
         Fill mobility matrix with zero when a particular destination
-        is not present in everyday.
+        is not present.
         """
 
         todos = set()
@@ -459,18 +459,33 @@ class Travel(object):
             output[key] = weekday
         return output
 
-    def median_weekday(self, weekday_data):
+    def median_weekday(self, data):
         """
         Apply the median to the weekday data.
 
-        :param weekday_data: Data from :py:func:`text_models.place.Travel.group_by_weekday`
-        :type weekday_data: dict
+        :param weekday_data: Data, e.g., :py:func:`text_models.place.Travel.displacement`
+        :type data: dict
         :rtype: dict
         """
+        class T(object):
+            def __init__(self, data):
+                self.data = data
+                # this.wdays = np.array([d.weekday() for d in self.dates])
 
+            def transform(self, value):
+                wdays = self.wdays
+                value = np.atleast_1d(value)
+                r = np.zeros(value.shape)
+                for wd in range(7):
+                    m = wdays == wd
+                    _ = (value[m] - self.data[wd]) / self.data[wd]
+                    r[m] = _
+                return r * 100.
+
+        weekday_data = self.group_by_weekday(data)
         output = dict()
         for key, data in weekday_data.items():
-            output[key] = {k: np.median(v) for k, v in data.items()}
+            output[key] = T({k: np.median(v) for k, v in data.items()})
         return output
 
     def percentage_by_weekday(self, data, baseline):
@@ -484,26 +499,35 @@ class Travel(object):
 
         """
 
-        wdays = [d.weekday() for d in self.dates]
-        output = dict()
-        for key, value in data.items():
-            base = baseline[key]
-            _ = [100 * (v - base[wd]) / base[wd] for wd, v in zip(wdays, value)]
-            output[key] = _
-        return output
+        for v in baseline.values():
+            v.wdays = np.array([d.weekday() for d in self.dates])
+        return self._apply(data, baseline)
 
-    def prob_weekday(self, weekday_data):
+    def prob_weekday(self, data):
         """
         Normal distribution of weekday data.
 
-        :param weekday_data: Data from :py:func:`text_models.place.Travel.group_by_weekday`
-        :type weekday_data: dict
+        :param data: Data, e.g., :py:func:`text_models.place.Travel.inside_mobility`
+        :type data: dict
         :rtype: dict
         """
+        class T(object):
+            def __init__(self, data):
+                self.data = data
 
+            def transform(self, value):
+                wdays = self.wdays
+                value = np.atleast_1d(value)
+                r = np.zeros(value.shape)
+                for wd in range(7):
+                    m = wdays == wd
+                    r[m] = self.data[wd].predict_proba(value[m])
+                return r
+
+        weekday_data = self.group_by_weekday(data)
         output = dict()
         for key, data in weekday_data.items():
-            output[key] = {k: Gaussian().fit(v) for k, v in data.items()}
+            output[key] = T({k: Gaussian().fit(v) for k, v in data.items()})
         return output
 
     def probability_by_weekday(self, data, baseline):
@@ -517,26 +541,29 @@ class Travel(object):
 
         """
 
-        wdays = np.array([d.weekday() for d in self.dates])
-        output = dict()
-        for key, value in data.items():
-            base = baseline[key]
-            value = np.atleast_1d(value)
-            r = np.zeros(value.shape)
-            for wd in range(7):
-                m = wdays == wd
-                _ = base[wd].predict_proba(value[m])
-                r[m] = _
-            output[key] = r
-        return output
+        for v in baseline.values():
+            v.wdays = np.array([d.weekday() for d in self.dates])
+
+        return self._apply(data, baseline)
+
+    @staticmethod
+    def _apply(data, func):
+        """
+        :param data: Data to apply :py:attr:`func`
+        :type data: dict
+        :param func: Functions with method transform
+        :type func: dict
+        """
+
+        return {k: func[k].transform(v) for k, v in data.items()}
 
 
 class BoundingBox(object):
     """
-    The lowest resolution, on mobility, is the centroids of
+    The lowest resolution, on mobility, is the centroid of
     the bounding box provided by Twitter. Each centroid is
-    associated with a label. This class provides this mapping
-    between the geo-localization and the centroids label. 
+    associated with a label. This class provides the mapping
+    between the geo-localization and the centroid's label. 
     """
 
     def __init__(self):
@@ -596,7 +623,7 @@ class BoundingBox(object):
 
     def label(self, data):
         """
-        The label of the closest bounding-box centroid to data
+        The label of the closest bounding-box centroid to the data
 
         :param data: A dictionary containing the country and the position
         :type data: dict
